@@ -40,7 +40,7 @@
 #'    opt = TRUE
 #' )
 #'
-#' @param data data frame containing the quantile summary data. For one-group studies, the input dataset may contain the following columns depending on the quantile scenario:
+#' @param data data frame containing the quantile summary data. For one-group studies, the input may contain the following columns depending on the quantile scenario:
 #' \describe{
 #'   \item{\code{'stduy.index'}}{stduy index or name}
 #'   \item{\code{'min.g1'}}{minimum value}
@@ -129,10 +129,10 @@
 #' )
 #' print(plot_2g)
 #'
-#' @references Alysha De Livera, Luke Prendergast, and Udara Kumaranathunga. A novel density-based approach for estimating unknown means, distribution visualisations, and meta-analyses of quantiles. \emph{Submitted for Review}, 2024, pre-print available here: <https://arxiv.org/abs/2411.10971>
-#' @references Marshall Freimer, Georgia Kollia, Govind S Mudholkar, and C Thomas Lin. A study of the generalized tukey lambda family. \emph{Communications in Statistics-Theory and Methods}, 17(10):3547–3567, 1988.
-#' @references Warren Gilchrist. \emph{Statistical modelling with quantile functions}. Chapman and Hall/CRC, 2000.
-#' @references P. J. van Staden and R. A. R. King. The quantile-based skew logistic distribution.  \emph{Statistics & Probability Letters}, 96:109–116, 2015.
+#' @references De Livera, A. M., Prendergast, L., & Kumaranathunga, U. (2024). A novel density-based approach for estimating unknown means, distribution visualisations and meta-analyses of quantiles. \emph{arXiv preprint arXiv:2411.10971}. <https://arxiv.org/abs/2411.10971>.
+#' @references Freimer, M., Kollia, G., Mudholkar, G. S., & Lin, C. T. (1988). A study of the generalized Tukey lambda family. \emph{Communications in Statistics—Theory and Methods, 17}(10), 3547–3567.
+#' @references Gilchrist, W. (2000). \emph{Statistical modelling with quantile functions}. Chapman & Hall/CRC.
+#' @references van Staden, P. J., & King, R. A. R. (2015). The quantile-based skew logistic distribution. \emph{Statistics & Probability Letters, 96}, 109–116.
 #' @export 
 #' 
 #' @importFrom gld dgl
@@ -278,194 +278,3 @@ plotdist <- function(data,
 }
 
 
-check.df <- function(df) {
-  #Assign 'study.index' if missing
-  if (!"study.index" %in% colnames(df)) {
-    warning("The 'study.index' column is missing. It has been added automatically as Study1, Study2, etc..")
-    df$study.index <- paste0("study", seq_len(nrow(df)))
-  }
-  #Check for Group 1 columns and Group 2 columns
-  s1_g1 <- c("study.index", "min.g1", "med.g1", "max.g1", "n.g1")
-  s2_g1 <- c("study.index", "q1.g1", "med.g1", "q3.g1")
-  s3_g1 <- c("study.index", "min.g1", "q1.g1", "med.g1", "q3.g1", "max.g1", "n.g1")
-  
-  valid_group1 <- all(s1_g1 %in% colnames(df)) ||
-    all(s2_g1 %in% colnames(df)) ||
-    all(s3_g1 %in% colnames(df))
-  
-  if (!valid_group1) {
-    stop("The group 1 does not have the required quantile columns for estimation.")
-  }
-  g2_present <- any(grepl("\\.g2$", colnames(df)))
-  if (g2_present) {
-    s1_g2 <- c("study.index", "min.g2", "med.g2", "max.g2", "n.g2")
-    s2_g2 <- c("study.index", "q1.g2", "med.g2", "q3.g2")
-    s3_g2 <- c("study.index", "min.g2", "q1.g2", "med.g2", "q3.g2", "max.g2", "n.g2")
-    
-    valid_group2 <- all(s1_g2 %in% colnames(df)) ||
-      all(s2_g2 %in% colnames(df)) ||
-      all(s3_g2 %in% colnames(df))
-    
-    if (!valid_group2) {
-      stop("The group 2 does not have the required quantile columns for estimation.")
-    }
-  }
-  
-  #Check for non-numeric values in quantile columns
-  invalid_rows_g1 <-NULL
-  invalid_rows_g2 <-NULL
-  quantile_cols_g1 <-grep("\\.g1$", colnames(df), value = TRUE)
-  quantile_cols_g2 <-grep("\\.g2$", colnames(df), value = TRUE)
-  
-  if (length(quantile_cols_g1)>0) {
-    invalid_rows_g1 <- which(rowSums(sapply(df[quantile_cols_g1], function(col) {
-      !is.finite(as.numeric(col))
-    })) > 0)
-  }
-  if (length(quantile_cols_g2)>0) {
-    invalid_rows_g2 <- which(rowSums(sapply(df[quantile_cols_g2], function(col) {
-      !is.finite(as.numeric(col))
-    })) > 0)
-  }
-  if (length(invalid_rows_g1)>0) {
-    warning(paste("Rows", paste(invalid_rows_g1, collapse = ", "), 
-                  "contain invalid data for Group 1 and will be skipped from density visualisation."))
-  }
-  if (length(invalid_rows_g2)>0) {
-    warning(paste("Rows", paste(invalid_rows_g2, collapse = ", "), 
-                  "contain invalid data for Group 2 and will be skipped from density visualisation."))
-  }
-  
-  return(list(df = df, invalid_rows_g1 = invalid_rows_g1, invalid_rows_g2 = invalid_rows_g2))
-}
-
-
-get.scenario <- function(data, gi) {
-  if (all(c(paste0("min.", gi), paste0("q1.", gi), paste0("med.", gi), 
-            paste0("q3.", gi), paste0("max.", gi)) %in% colnames(data))) {
-    return("5-number")
-  } else if (all(c(paste0("min.", gi), paste0("med.", gi), paste0("max.", gi)) %in% colnames(data))) {
-    return("min-med-max")
-  } else if (all(c(paste0("q1.", gi), paste0("med.", gi), paste0("q3.", gi)) %in% colnames(data))) {
-    return("q1-med-q3")
-  } else {
-    stop(paste("Invalid or incomplete data for group", gi))
-  }
-}
-
-
-get.density <- function(data, gi, summary_type, group_label, xmin, xmax, length.out, opt) {
-  group_data <- data.frame()
-  
-  if (is.null(xmin) || is.null(xmax)) {
-    if (summary_type == "5-number" || summary_type == "min-med-max") {
-      if (is.null(xmin)) xmin <-min(data[[paste0("min.", gi)]], na.rm=TRUE)
-      if (is.null(xmax)) xmax <-max(data[[paste0("max.", gi)]], na.rm=TRUE)
-    } else if (summary_type == "q1-med-q3") {
-      if (is.null(xmin) || is.null(xmax)) {
-        stop("Please set argument 'xmin' and 'xmax' to compute density data (as default values cannot be computed for the given quantile scenario)")
-      }
-    }
-  }
-  
-  for (i in seq_len(nrow(data))) {
-    n <- data[[paste0("n.", gi)]][i]
-    
-    if (summary_type == "5-number") {
-      q <- as.numeric(data[i, c(paste0("min.", gi), paste0("q1.", gi), paste0("med.", gi), 
-                                paste0("q3.", gi), paste0("max.", gi))])
-      dens_out <- est.density.five(min = q[1], q1 = q[2], med = q[3], q3 = q[4], max = q[5], n = n, opt = opt)
-      x_vals <- seq(xmin, xmax, length.out = length.out)
-      y_vals <- dgl(x_vals, lambda1 = dens_out$parameters[1], lambda2 = dens_out$parameters[2], 
-                    lambda3 = dens_out$parameters[3], lambda4 = dens_out$parameters[4])
-    } else if (summary_type == "min-med-max") {
-      q <- as.numeric(data[i, c(paste0("min.", gi), paste0("med.", gi), paste0("max.", gi))])
-      dens_out <- est.density.minq2max(min = q[1], med = q[2], max = q[3], n = n, opt = opt)
-      x_vals <- seq(xmin, xmax, length.out = length.out)
-      y_vals <- dsl(x_vals, dens_out$parameters)
-    } else if (summary_type == "q1-med-q3") {
-      q <- as.numeric(data[i, c(paste0("q1.", gi), paste0("med.", gi), paste0("q3.", gi))])
-      dens_out <- est.density.q1q2q3(q1 = q[1], med = q[2], q3 = q[3], n = n, opt = opt)
-      x_vals <- seq(xmin, xmax, length.out = length.out)
-      y_vals <- dsl(x_vals, dens_out$parameters)
-    }
-    
-    group_density <- data.frame(x=x_vals, y=y_vals, Study=data$study.index[i], Group=group_label)
-    group_data <- rbind(group_data, group_density)
-  }
-  
-  return(group_data)
-}
-
-
-get.pooled.density <- function(data, gi, summary_type, group_label, xmin, xmax, length.out, opt) {
-  
-  if (is.null(xmin) || is.null(xmax)) {
-    if (summary_type == "5-number" || summary_type == "min-med-max") {
-      if (is.null(xmin)) xmin <-min(data[[paste0("min.", gi)]], na.rm=TRUE)
-      if (is.null(xmax)) xmax <-max(data[[paste0("max.", gi)]], na.rm=TRUE)
-    } else if (summary_type == "q1-med-q3") {
-      if (is.null(xmin) || is.null(xmax)) {
-        stop("Please set argument 'xmin' and 'xmax' to compute density data (as default values cannot be computed for the given quantile scenario)")
-      }
-    }
-  }
-  
-  if (summary_type == "5-number") {
-    data$l1 <-NA
-    data$l2 <-NA
-    data$l3 <-NA
-    data$l4 <-NA
-  } else {
-    data$lambda <-NA
-    data$eta <-NA
-    data$delta <-NA
-  }
-  
-  #Store parameters for each row
-  for (i in seq_len(nrow(data))) {
-    n <- data[[paste0("n.", gi)]][i]
-    if (summary_type == "5-number") {
-        q <- as.numeric(data[i, c(paste0("min.", gi), paste0("q1.", gi), paste0("med.", gi), 
-                                paste0("q3.", gi), paste0("max.", gi))])
-        dens_out <- est.density.five(min = q[1], q1 = q[2], med = q[3], q3 = q[4], max = q[5], n = n, opt = opt)
-        data$l1[i] <- dens_out$parameters[1]
-        data$l2[i] <- dens_out$parameters[2]
-        data$l3[i] <- dens_out$parameters[3]
-        data$l4[i] <- dens_out$parameters[4]
-    } else if(summary_type == "min-med-max"){
-        q <- as.numeric(data[i, c(paste0("min.", gi), paste0("med.", gi), paste0("max.", gi))])
-        dens_out <- est.density.minq2max(min = q[1], med = q[2], max = q[3], n = n, opt = opt)
-        data$lambda[i] <- dens_out$parameters[1]
-        data$eta[i] <- dens_out$parameters[2]
-        data$delta[i] <- dens_out$parameters[3]
-    } else if(summary_type == "q1-med-q3"){
-        q <- as.numeric(data[i, c(paste0("q1.", gi), paste0("med.", gi), paste0("q3.", gi))])
-        dens_out <- est.density.q1q2q3(q1 = q[1], med = q[2], q3 = q[3], n = n, opt = opt)
-        data$lambda[i] <- dens_out$parameters[1]
-        data$eta[i] <- dens_out$parameters[2]
-        data$delta[i] <- dens_out$parameters[3]
-    }
-  }
-  
-  # weights
-  data$weight <- data[[paste0("n.", gi)]]/sum(data[[paste0("n.", gi)]])
-  
-  # pooled parameters
-  if (summary_type == "5-number"){
-    pooled.l1 <-sum(data$weight*data$l1,na.rm =TRUE)
-    pooled.l2 <- sum(data$weight*data$l2,na.rm =TRUE)
-    pooled.l3 <-sum(data$weight*data$l3,na.rm =TRUE)
-    pooled.l4 <- sum(data$weight*data$l4,na.rm =TRUE)
-    x_vals <-seq(xmin, xmax, length.out = length.out)
-    y_vals <- dgl(x_vals, lambda1 =pooled.l1, lambda2 =pooled.l2, lambda3 =pooled.l3, lambda4 =pooled.l4)
-  } else{
-      pooled.lambda <-sum(data$weight*data$lambda, na.rm =TRUE)
-      pooled.eta <-sum(data$weight*data$eta, na.rm =TRUE)
-      pooled.delta <-sum(data$weight*data$delta, na.rm =TRUE)
-      x_vals <-seq(xmin, xmax, length.out =length.out)
-      y_vals <-dsl(x_vals, c(pooled.lambda, pooled.eta, pooled.delta))
-  }
-  
-  return(data.frame(x=x_vals, y=y_vals, Group = paste0(group_label, " (Pooled)"), Study="Pooled"))
-}
